import {
  select, 
  json, 
  geoPath,
  geoCentroid,
  geoAlbersUsa,
  zoom,
  event,
  scaleSqrt,
  max,
} from 'd3';

import { feature, merge } from 'topojson';
import { loadAndProcessData } from './loadAndProcessData';

const svg = select('svg');
let data;
const width = +svg.attr('width');
const height = +svg.attr('height');

const g = svg.append('g');
svg.call(zoom().on('zoom', ()=>{
  g.attr('transform', event.transform)
}));

let sizeScale = null;
const USmap = geoAlbersUsa();
const pathGenerator = map => geoPath().projection(map);
const radiusValue = d => d.properties['TotalVolume'];

loadAndProcessData().then([data,date] => {  
  
  sizeScale = scaleSqrt()
    .domain([0, max(data.features, radiusValue)])
    .range([0, 4]);
  
  const dates = data.features
  
  render(data);
});


const render = (data) => {
  data.features.forEach(d => !d.properties["TotalVolume"]
                        ?    d.properties["TotalVolume"] = 0
                        : null)

  
  g.selectAll('path')
    .data(data.features)
    .enter().append('path')
  	.attr('class', 'states')
    .attr('d', pathGenerator(USmap)) 
    .attr('fill', d => d.properties['TotalVolume'] ? '#fecccc' : '#e8e8e8')
  	.append('title')
  	.text(d => d.properties['State']
            ? [d.properties['State'],d.properties['TotalVolume']].join(': ') 
            : 'Missing Data');
  
  data.features.pop() //not sure why last 2 arnt working
  data.features.pop() //not sure why last 2 arnt working
  


  g.append("g")
    .attr("class","state-circle")
    .selectAll("circle")
    .data(data.features)
    .enter().append("circle")
    .attr('cx', d => USmap(geoCentroid(d))[0])
    .attr('cy', d => USmap(geoCentroid(d))[1])
    .attr('r',d => sizeScale(radiusValue(d)))

};     






